Struct ShortFlags

struct ShortFlags<'s> { ... }

Walk through short flags within a ParsedArg

Implementations

impl<'s> ShortFlags<'s>

fn advance_by(self: &mut Self, n: usize) -> Result<(), usize>

Move the iterator forward by n short flags

fn is_empty(self: &Self) -> bool

No short flags left

fn is_negative_number(self: &Self) -> bool

Does the short flag look like a number

Ideally call this before doing any iterator

fn next_flag(self: &mut Self) -> Option<Result<char, &'s OsStr>>

Advance the iterator, returning the next short flag on success

On error, returns the invalid-UTF8 value

fn next_value_os(self: &mut Self) -> Option<&'s OsStr>

Advance the iterator, returning everything left as a value

impl<'s> Clone for ShortFlags<'s>

fn clone(self: &Self) -> ShortFlags<'s>

impl<'s> Debug for ShortFlags<'s>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'s> Freeze for ShortFlags<'s>

impl<'s> Iterator for ShortFlags<'s>

fn next(self: &mut Self) -> Option<<Self as >::Item>

impl<'s> RefUnwindSafe for ShortFlags<'s>

impl<'s> Send for ShortFlags<'s>

impl<'s> Sync for ShortFlags<'s>

impl<'s> Unpin for ShortFlags<'s>

impl<'s> UnsafeUnpin for ShortFlags<'s>

impl<'s> UnwindSafe for ShortFlags<'s>

impl<I> IntoIterator for ShortFlags<'s>

fn into_iter(self: Self) -> I

impl<T> Any for ShortFlags<'s>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ShortFlags<'s>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ShortFlags<'s>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for ShortFlags<'s>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for ShortFlags<'s>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for ShortFlags<'s>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for ShortFlags<'s>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ShortFlags<'s>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ShortFlags<'s>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>